@@ -6,8 +6,8 @@ from __future__ import absolute_import, division, print_function
 from future import standard_library
 standard_library.install_aliases()
 
-import json
-import os, os.path
+import os
+import os.path
 import shutil
 import sys
 from tempfile import NamedTemporaryFile
@@ -16,8 +16,9 @@ from htrc.metadata import get_metadata, get_volume_metadata
 import htrc.volumes
 import htrc.workset
 import htrc.tools.mallet
+
 from argparse import ArgumentParser
-import htrc.tools.topicexplorer
+# import htrc.tools.topicexplorer
 from htrc.lib.cli import bool_prompt
 from htrc.util.resolve import *
 
@@ -25,18 +26,37 @@ from htrc.util.resolve import *
 def download_parser(parser=None):
     if parser is None:
         parser = ArgumentParser()
-    parser.add_argument("-u", "--username", help="HTRC username")
-    parser.add_argument("-p", "--password", help="HTRC password")
+    #parser.add_argument("-u", "--username", help="HTRC username")
+    #parser.add_argument("-p", "--password", help="HTRC password")
     parser.add_argument("file", nargs='?', default=sys.stdin,
-        help="workset path[s]")
+        help="Workset path[s]")
     parser.add_argument("-f", "--force", action='store_true', 
-        help="remove folder if exists")
-    parser.add_argument("-o", "--output", help="output directory",
+        help="Remove folder if exists")
+    parser.add_argument("-o", "--output", help="Output directory",
         default='/media/secure_volume/workset/')
+    parser.add_argument("-hf", "--remove-headers-footers", action='store_true',
+        help="Remove headers and footers from individual pages and save in a separate csv file for inspection")
+    parser.add_argument("-hfc", "--remove-headers-footers-and-concat", action='store_true',
+        help="Remove headers and footers from individual pages and save in a separate csv file for inspection then concatenate pages")
+    parser.add_argument("-w", "--window-size", required=False, type=int, metavar="N", default=6,
+                        help="How many pages ahead does the header/footer extractor algorithm look to find potential "
+                             "matching headers/footers (higher value gives potentially more accurate results on lower "
+                             "quality OCR volumes at the expense of runtime)")
+    parser.add_argument("-msr", "--min-similarity-ratio", required=False, type=float, metavar="N", default=0.7,
+                        help="The minimum string similarity ratio required for the Levenshtein distance fuzzy-matching "
+                             "algorithm to declare that two headers are considered 'the same' (the higher the value, up "
+                             "to a max of 1.0, the more strict the matching has to be; lower values allow for more "
+                             "fuzziness to account for OCR errors)")
+    parser.add_argument("-s", "--skip-removed-hf", action='store_true',
+                        help="Skip creating a saved report of the removed headers and footers for each page for inspection")
+    parser.add_argument("--parallelism", required=False, type=int, metavar="N", default=os.cpu_count(),
+                        help="The max number of concurrent tasks to start when downloading or removing headers/footers")
+    parser.add_argument("--batch-size", required=False, type=int, metavar="N", default=250,
+                        help="The max number of volumes to download at a time from DataAPI")
     parser.add_argument("-c", "--concat", action='store_true',
-        help="concatenate a volume's pages in to a single file")
+        help="Concatenate a volume's pages in to a single file")
     parser.add_argument("-m", "--mets", action='store_true',
-                        help="add volume's METS file")
+                        help="Add volume's METS file")
     parser.add_argument("-pg", "--pages",action='store_true',
         help="Download given page numbers of a volumes.")
     parser.add_argument("-t", "--token", help="JWT for volumes download.")
@@ -47,17 +67,17 @@ def download_parser(parser=None):
     parser.add_argument("-dk", "--datakey", help="Client key file for mutual TLS with Data API.")
     return parser
 
+
 def add_workset_path(parser=None):
     if parser is None:
         parser = ArgumentParser()
-    parser.add_argument("path", nargs='+', help="workset path[s]")
+    parser.add_argument("path", nargs='+', help="Workset path[s]")
     return parser
 
-    
 
 def main():
     parser = ArgumentParser()
-    parser.add_argument('-d', '--debug', help="print long debug messages",
+    parser.add_argument('-d', '--debug', help="Print long debug messages",
                         action='store_true')
     parsers = parser.add_subparsers(help="select a command")
 
@@ -78,18 +98,19 @@ def main():
         help="Download HathiTrust volumes to disk [requires auth]")
     download_parser(parser_download)
     parser_download.set_defaults(func='download')
-
+    
+    
     # Run helper
     parser_run = parsers.add_parser('run', help="Run a built-in algorithm.")
-    run_parsers = parser_run.add_subparsers(help="select a command")
+    run_parsers = parser_run.add_subparsers(help="Select a command")
 
     parser_mallet = run_parsers.add_parser('mallet')
     htrc.tools.mallet.populate_parser(parser_mallet)
     parser_mallet.set_defaults(run='mallet')
     
-    parser_topicexplorer = run_parsers.add_parser('topicexplorer')
-    htrc.tools.topicexplorer.populate_parser(parser_topicexplorer)
-    parser_topicexplorer.set_defaults(run='topicexplorer')
+    # parser_topicexplorer = run_parsers.add_parser('topicexplorer')
+    # htrc.tools.topicexplorer.populate_parser(parser_topicexplorer)
+    # parser_topicexplorer.set_defaults(run='topicexplorer')
     
     parser_run.set_defaults(func='run')
 
@@ -121,8 +142,8 @@ def main():
             sys.exit(1)
         if args.run == 'mallet':
             htrc.tools.mallet.main(args.path, args.k, args.iter)
-        if args.run == 'topicexplorer':
-            htrc.tools.topicexplorer.main(args.path, args.k, args.iter)
+        # if args.run == 'topicexplorer':
+        #     htrc.tools.topicexplorer.main(args.path, args.k, args.iter)
     elif args.func == 'download':
         if os.path.exists(args.output):
             if args.force or bool_prompt('Folder {} exists. Delete?'.format(args.output), default=False):
@@ -131,10 +152,25 @@ def main():
             else:
                 print("Please choose another output folder and try again.")
                 sys.exit(1)
-
+        
+        if args.concat and args.remove_headers_footers:
+            print("Cannot set both concat and remove-headers-footers")
+            sys.exit(1)
+        if args.concat and args.remove_headers_footers_and_concat:
+            print("Cannot set both concat and remove-headers-footers-and-concat")
+            sys.exit(1)
+        if args.remove_headers_footers and args.remove_headers_footers_and_concat:
+            print("Cannot set both remove_headers_footers and remove_headers_footers_and_concat")
+            sys.exit(1)
+        if args.mets and args.remove_headers_footers_and_concat:
+            print("Cannot set both mets and remove_headers_footers_and_concat")
+            sys.exit(1)
         if args.pages:
             if args.mets and args.concat:
-                print ("Cannot set both concat and mets with pages")
+                print("Cannot set both concat and mets with pages")
+                sys.exit(1)
+            if args.mets and args.remove_headers_footers_and_concat:
+                print("Cannot set both mets and remove_headers_footers_and_concat with pages")
                 sys.exit(1)
 
         try:
@@ -143,6 +179,7 @@ def main():
             print("Invalid identifier:", args.file)
             sys.exit(1)
 
+
 def resolve_and_download(args):
     if args.file == sys.stdin:
         # For use with UNIX pipes
@@ -207,6 +244,7 @@ def download(args):
         else:
             raise e
 
+
 def download_with_tempfile(args, volumes):
     f = NamedTemporaryFile()
     for volume in volumes:
